# Changelog

## Version 0.1.3

- Add CSS styles for flexboxes, embeddable in markdown with a syntax like:
```text
.flex[
.half-flex-container[
... my first column ...
]
.half-flex-container[
... my other column
]
]
```
- Add a `.allow-wrap` CSS class for forcing code to wrap in markdown
- Update html template so that autogenerated section title slides have the `premark-section-title` class, which makes their headings larger via CSS.

## Version 0.1.2

- Update manifest file to include Premark's default configuration when the package is installed.

## Version 0.1.1

- Fix section auto-numbering (see [#10](https://github.com/eswan18/premark/issues/10)).

## Version 0.1.0

- Overhaul interface of both the CLI and the `Presentation` class.
- Support config files as yaml.

## Version 0.0.9

- First release
